#include "UUPV.h"
#include "OmicronUtils.h"

bool UPV::GetParameters(const string aOptFile, Segments *aInSeg){
  if(!IsTextFile(aOptFile)) return false;
  if(!aInSeg->GetLiveTime()) return false;
  
  // locals
  IO *io = new IO(aOptFile.c_str());
  string sVar;
  vector <string> sVect;
   
  //*****************************************
  //*****            TARGET             *****
  //*****************************************

  // path to trigger files
  if(!io->GetOpt("TARGET","TRIGGERS", target_trigfiles)) target_trigfiles=".";
  if(IsDirectory(target_trigfiles)) target_trigfiles+="/*.root";// if a directory is provided, scan all files

  // standard omicron triggers
  if(io->GetOpt("TARGET","OMICRON", sVar)) target_trigfiles=GetOmicronFilePattern(sVar,aInSeg->GetStart(0),aInSeg->GetEnd(aInSeg->GetNsegments()-1));

  // clustering dt
  if(!io->GetOpt("TARGET","CLUSTERDT", target_clusterdt)) target_clusterdt=0.1;

  // clustering snrmin
  if(!io->GetOpt("TARGET","SNRMIN", target_snrmin)) target_snrmin=7;

  // frequency min
  if(!io->GetOpt("TARGET","FREQUENCYMIN", target_freqmin)) target_freqmin=-1.0;

  // frequency max
  if(!io->GetOpt("TARGET","FREQUENCYMAX", target_freqmax)) target_freqmax=1e20;

  if(!io->GetOpt("TARGET","SNRTHR", snrthr)){
    snrthr.push_back(target_snrmin);
    snrthr.push_back(1.5*target_snrmin);
    snrthr.push_back(1.5*1.5*target_snrmin);
  }
  
  //*****************************************
  //*****            SOURCE             *****
  //*****************************************

  // path to trigger files
  io->GetAllOpt("SOURCE","TRIGGERS", sVect);
  for(int i=0; i<(int)sVect.size(); i++){
    if(IsDirectory(sVect[i])) source_trigfiles.push_back(sVect[i]+"/*.root");
    else source_trigfiles.push_back(sVect[i]);
  }
  sVect.clear();

  // standard omicron triggers
  if(io->GetAllOpt("SOURCE","OMICRON", sVect)) for(int i=0; i<(int)sVect.size(); i++) source_trigfiles.push_back(GetOmicronFilePattern(sVect[i],aInSeg->GetStart(0),aInSeg->GetEnd(aInSeg->GetNsegments()-1)));
  sVect.clear();

  // clustering dt
  if(!io->GetOpt("SOURCE","CLUSTERDT", source_clusterdt)) source_clusterdt=0.1;

  //*****************************************
  //*****              COINC            *****
  //*****************************************
  if(!io->GetOpt("COINC","TIMEWIN", C2_dt)) C2_dt=1.0;

  //*****************************************
  //*****              VETO             *****
  //*****************************************
  if(!io->GetOpt("VETO","UMIN", veto_umin))   veto_umin=10;
  if(!io->GetOpt("VETO","UPMIN", veto_upmin)) veto_upmin=0.5;
  if(io->GetOpt("VETO","PERF", veto_perf)){
    if(veto_perf.size()==1) veto_perf.push_back(0);
    else if(veto_perf.size()==0){ veto_perf.push_back(0);  veto_perf.push_back(0); }
    else;
  }
  else{ veto_perf.push_back(0);  veto_perf.push_back(0); }

  //*****************************************
  //*****             OUTPUT            *****
  //*****************************************
  if(!io->GetOpt("OUTPUT","DIRECTORY", outdir)||!IsDirectory(outdir)) outdir=".";
  if(!io->GetOpt("OUTPUT","VERBOSITY", verbosity)) verbosity=0;
  
  delete io;
  return true;
}

